@@ -1,10 +1,11 @@
+import traceback
 import typing
 from dataclasses import dataclass
 
 from iwf.command_request import _to_idl_command_request
 from iwf.command_results import from_idl_command_results
 from iwf.communication import Communication
-from iwf.iwf_api.iwf_api.models import (
+from iwf.iwf_api.models import (
     EncodedObject,
     KeyValue,
     WorkflowStateExecuteRequest,
@@ -14,7 +15,7 @@ from iwf.iwf_api.iwf_api.models import (
     WorkflowWorkerRpcRequest,
     WorkflowWorkerRpcResponse,
 )
-from iwf.iwf_api.iwf_api.types import Unset
+from iwf.iwf_api.types import Unset
 from iwf.object_encoder import ObjectEncoder
 from iwf.persistence import Persistence
 from iwf.registry import Registry
@@ -33,12 +34,12 @@ default_worker_options = WorkerOptions(ObjectEncoder.default)
 
 
 class WorkerService:
-    api_path_workflow_state_wait_until: typing.ClassVar[
-        str
-    ] = "/api/v1/workflowState/start"
-    api_path_workflow_state_execute: typing.ClassVar[
-        str
-    ] = "/api/v1/workflowState/decide"
+    api_path_workflow_state_wait_until: typing.ClassVar[str] = (
+        "/api/v1/workflowState/start"
+    )
+    api_path_workflow_state_execute: typing.ClassVar[str] = (
+        "/api/v1/workflowState/decide"
+    )
     api_path_workflow_worker_rpc: typing.ClassVar[str] = "/api/v1/workflowWorker/rpc"
 
     def __init__(
@@ -47,6 +48,21 @@ class WorkerService:
         self._registry = registry
         self._options = options
 
+    @staticmethod
+    def handle_worker_error(exception: Exception):
+        """
+        Handle the exception/error of worker so that Temporal/Cadence WebUI can show the error nicely.
+        Example usage (in Flask):
+            @_flask_app.errorhandler(Exception)
+            def internal_error(exception):
+                return _worker_service.handle_worker_error(exception), 500
+        """
+        stacktrace = traceback.format_exc()
+        index = stacktrace.index("iwf-python-sdk/iwf/worker_service.py")
+        return "WorkerExecutionError: {0}; StackTrace:{1}".format(
+            exception, stacktrace[index:]
+        )
+
     def handle_workflow_worker_rpc(
         self,
         request: WorkflowWorkerRpcRequest,
