@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 from typing import Any, Optional
 
-from iwf.iwf_api.iwf_api.models import (
+from iwf.iwf_api.models import (
     ExecuteApiFailurePolicy,
     PersistenceLoadingPolicy,
     RetryPolicy,
@@ -13,19 +13,34 @@ from iwf.iwf_api.iwf_api.models import (
 @dataclass
 class WorkflowStateOptions:
     state_id: Optional[str] = None
-    search_attributes_loading_policy: Optional[PersistenceLoadingPolicy] = None
+    # apply for both waitUntil and execute API
     data_attributes_loading_policy: Optional[PersistenceLoadingPolicy] = None
+    search_attributes_loading_policy: Optional[PersistenceLoadingPolicy] = None
+    # below are wait_until API specific options:
     wait_until_api_timeout_seconds: Optional[int] = None
-    execute_api_timeout_seconds: Optional[int] = None
     wait_until_api_retry_policy: Optional[RetryPolicy] = None
-    execute_api_retry_policy: Optional[RetryPolicy] = None
     wait_until_api_failure_policy: Optional[WaitUntilApiFailurePolicy] = None
+    wait_until_api_data_attributes_loading_policy: Optional[
+        PersistenceLoadingPolicy
+    ] = None
+    wait_until_api_search_attributes_loading_policy: Optional[
+        PersistenceLoadingPolicy
+    ] = None
+    # below are execute API specific options:
+    execute_api_timeout_seconds: Optional[int] = None
+    execute_api_retry_policy: Optional[RetryPolicy] = None
     """
         note that the failing handling state will take the same input as the failed state
         the type is Optional[type[WorkflowState]] but there is an issue with type hint...
         TODO fix this type hint
     """
     execute_failure_handling_state: Optional[type] = None
+    execute_api_data_attributes_loading_policy: Optional[PersistenceLoadingPolicy] = (
+        None
+    )
+    execute_api_search_attributes_loading_policy: Optional[PersistenceLoadingPolicy] = (
+        None
+    )
 
 
 def _to_idl_state_options(
@@ -42,8 +57,24 @@ def _to_idl_state_options(
         return res
     assert isinstance(options, WorkflowStateOptions)
 
+    if options.wait_until_api_search_attributes_loading_policy is not None:
+        res.wait_until_api_search_attributes_loading_policy = (
+            options.wait_until_api_search_attributes_loading_policy
+        )
+    if options.execute_api_search_attributes_loading_policy is not None:
+        res.execute_api_search_attributes_loading_policy = (
+            options.execute_api_search_attributes_loading_policy
+        )
     if options.search_attributes_loading_policy is not None:
         res.search_attributes_loading_policy = options.search_attributes_loading_policy
+    if options.wait_until_api_data_attributes_loading_policy is not None:
+        res.wait_until_api_data_attributes_loading_policy = (
+            options.wait_until_api_data_attributes_loading_policy
+        )
+    if options.execute_api_data_attributes_loading_policy is not None:
+        res.execute_api_data_attributes_loading_policy = (
+            options.execute_api_data_attributes_loading_policy
+        )
     if options.data_attributes_loading_policy is not None:
         res.data_attributes_loading_policy = options.data_attributes_loading_policy
     if options.wait_until_api_failure_policy is not None:
